@@ -1,21 +1,21 @@
 cluspca <- function(data,nclus,ndim,alpha=NULL,method=c("RKM","FKM"),center = TRUE, scale = TRUE, rotation="none",nstart=100,smartStart=NULL,seed=1234)
 {
   #### A single cluster gives the MCA solution
-  if (nclus == 1) { 
+  if (nclus == 1) {
     nstart = 1
     data = data.frame(data)
     n = nrow(data)
     #asymmetric map, biplot
     outp = princomp(data, scale = scale, center = center)
     out=list()
-    out$obscoord=outp$scores[,1:ndim] # observations coordinates 
-    out$attcoord=data.matrix(outp$loadings[,1:ndim]) # attributes coordinates 
+    out$obscoord=outp$scores[,1:ndim] # observations coordinates
+    out$attcoord=data.matrix(outp$loadings[,1:ndim]) # attributes coordinates
     rownames(out$obscoord) = rownames(data)
     rownames(out$attcoord) = colnames(data)
-   
+
     out$centroid = 0 #center
     out$cluster = rep(1,n)#cluster
-    names(out$cluster) = rownames(data) 
+    names(out$cluster) = rownames(data)
     out$criterion = 1 # criterion
     out$size=n #as.integer(aa)  #round((table(cluster)/sum( table(cluster)))*100,digits=1)
     out$odata=data.frame(lapply(data.frame(data),factor))
@@ -31,17 +31,17 @@ cluspca <- function(data,nclus,ndim,alpha=NULL,method=c("RKM","FKM"),center = TR
       warning('The ndim argument is missing. ndim was set to nclus - 1')
       ndim = nclus - 1
     }
-    
-    if (ndim >= nclus) {
-      stop('The number of clusters should be larger than the number of dimensions.')
-    }
-    
+
+   # if (ndim >= nclus) {
+  #    stop('The number of clusters should be larger than the number of dimensions.')
+  #  }
+
     method <- match.arg(method, c("RKM", "rkm","rKM","FKM", "fkm","fKM"), several.ok = T)[1]
     method <- toupper(method)
-    
-    #  If alpha = .5 gives RKM, alpha=1 PCA and alpha =0  FKM. 
+
+    #  If alpha = .5 gives RKM, alpha=1 PCA and alpha =0  FKM.
     if (is.null(alpha) == TRUE)
-    {  
+    {
       if (method == "RKM") {
         alpha = .5
       } else if (method == "FKM") {
@@ -50,14 +50,14 @@ cluspca <- function(data,nclus,ndim,alpha=NULL,method=c("RKM","FKM"),center = TR
     }
     odata = data
     data =  scale(data, center = center, scale = scale)
-    
+
     data = data.matrix(data)
     n = dim(data)[1]
     m = dim(data)[2]
     conv=1e-6  # convergence criterion
     func={}; AA = {}; FF = {}; YY = {}; UU={}
     for (run in c(1:nstart)) {
-      
+
       # Starting method
       if(is.null(smartStart)){
         myseed=seed+run
@@ -66,17 +66,19 @@ cluspca <- function(data,nclus,ndim,alpha=NULL,method=c("RKM","FKM"),center = TR
       }else{
         randVec=smartStart
       }
-      
+
       U = dummy(randVec)
+     # U = data.matrix(fac2disj(randVec))
       #update A
-      P = U%*%pseudoinverse(t(U)%*%U)%*%t(U)
+      pseudoinvU = chol2inv(chol(t(U)%*%U))
+      P = U%*%pseudoinvU%*%t(U)
       R = t(data)%*%((1-alpha)*P-(1-2*alpha)*diag(n))%*%data
       #A = suppressWarnings(eigs_sym(R,ndim)$vectors)
       A = eigen(t(data)%*%((1-alpha)*P-(1-2*alpha)*diag(n))%*%data)$vectors
       A = A[,1:ndim]
       #update Y
       G = data%*%A
-      Y = pseudoinverse(t(U)%*%U)%*%t(U)%*%G
+      Y = pseudoinvU%*%t(U)%*%G
       f = alpha*ssq(data - G%*%t(A))+(1-alpha)*ssq(data%*%A-U%*%Y)
       f = as.numeric(f) #fixes convergence issue 01 Nov 2016
       fold = f + 2 * conv*f
@@ -86,26 +88,27 @@ cluspca <- function(data,nclus,ndim,alpha=NULL,method=c("RKM","FKM"),center = TR
         fold=f
         iter=iter+1
         outK = try(kmeans(G,centers=Y,nstart=100),silent=T)
-        
+
         if(is.list(outK)==FALSE){
-          outK = EmptyKmeans(G,centers=Y)  
+          outK = EmptyKmeans(G,centers=Y)
           #  break
         }
-        
+
         v = as.factor(outK$cluster)
         U = diag(nlevels(v))[v,] #dummy cluster membership
-        
+        pseudoinvU = chol2inv(chol(t(U)%*%U))
         # update A
-        P = U%*%pseudoinverse(t(U)%*%U)%*%t(U)
-        R = t(data)%*%((1-alpha)*P-(1-2*alpha)*diag(n))%*%data
+        P = U%*%pseudoinvU%*%t(U)
+        #R = t(data)%*%((1-alpha)*P-(1-2*alpha)*diag(n))%*%data
         #A = suppressWarnings(eigs_sym(R,ndim)$vectors)
         A = eigen(t(data)%*%((1-alpha)*P-(1-2*alpha)*diag(n))%*%data)$vectors
         A = A[,1:ndim]
         G = data %*% A
         #update Y
-        Y = pseudoinverse(t(U)%*%U)%*%t(U)%*%G
+        Y = pseudoinvU%*%t(U)%*%G
         # criterion
         f = alpha*ssq(data - G%*%t(A))+(1-alpha)*ssq(data%*%A-U%*%Y)
+        f = as.numeric(f)
       }
       func[run] = f
       #fpXunc[run]=fpX
@@ -114,13 +117,13 @@ cluspca <- function(data,nclus,ndim,alpha=NULL,method=c("RKM","FKM"),center = TR
       YY[[run]] = Y
       UU[[run]] = U
     }
-    
-    
+
+
     ##reorder according to cluster size
     mi = which.min(func)
     U=UU[[mi]]
     cluster = apply(U,1,which.max)
-    
+
     #csize = round((table(cluster)/sum( table(cluster)))*100,digits=2)
     size = table(cluster)
     aa = sort(size,decreasing = TRUE)
@@ -129,41 +132,41 @@ cluspca <- function(data,nclus,ndim,alpha=NULL,method=c("RKM","FKM"),center = TR
     centroid = YY[[mi]]
     centroid = centroid[as.integer(names(aa)),]
     #######################
-    
+
     ### rotation options ###
     if (rotation == "varimax") { #with Kaiser Normalization
       AA[[mi]] = varimax(AA[[mi]])$loadings[1:m,1:ndim]
       FF[[mi]] = data%*%AA[[mi]]
       #update center
-      centroid = pseudoinverse(t(U)%*%U)%*%t(U)%*%FF[[mi]] 
+      centroid =  chol2inv(chol(t(U)%*%U))%*%t(U)%*%FF[[mi]]
       centroid = centroid[as.integer(names(aa)),]
     } else if (rotation == "promax") {
       AA[[mi]] = promax(AA[[mi]])$loadings[1:m,1:ndim]
       FF[[mi]] = data%*%AA[[mi]]
       #update center
-      centroid = pseudoinverse(t(U)%*%U)%*%t(U)%*%FF[[mi]] 
+      centroid =  chol2inv(chol(t(U)%*%U))%*%t(U)%*%FF[[mi]]
       centroid = centroid[as.integer(names(aa)),]
     }
-    
+
     #  distB = sum(diag(t(AA[[mi]])%*% AA[[mi]]))
     #  distG = sum(diag(t(centroid)%*% centroid))
     #  gamma = ((nclus/m)* distB/distG)^.25
-    
+
     #  AA[[mi]] = (1/gamma)*AA[[mi]]
     #  centroid = gamma*centroid
     #  FF[[mi]] = gamma*FF[[mi]]
-    
+
     ##########################
-    
+
     #assign output
     out=list()
     mi = which.min(func)
-    out$obscoord = FF[[mi]]
+    out$obscoord = apply(FF[[mi]],2, as.numeric) #fixed complex output 16-04-2018
     rownames(out$obscoord) = rownames(data)
-    out$attcoord = data.matrix(AA[[mi]])#[1:m,1:ndim]
+    out$attcoord = data.matrix(apply(AA[[mi]],2, as.numeric))#[1:m,1:ndim] 
     rownames(out$attcoord) = colnames(data)
-    out$centroid = centroid #YY[[mi]]
-    names(cluster) = rownames(data) 
+    out$centroid = apply(centroid, 2, as.numeric) #YY[[mi]]
+    names(cluster) = rownames(data)
     out$cluster = cluster #apply(U,1,which.max)
     out$criterion = func[mi]
     out$size = as.integer(aa) #round((table(cluster)/sum(table(cluster)))*100,digits=1)
@@ -172,10 +175,10 @@ cluspca <- function(data,nclus,ndim,alpha=NULL,method=c("RKM","FKM"),center = TR
     out$center = center
     out$nstart = nstart
     class(out) = "cluspca"
-    return(out)   
+    return(out)
   }
 }
 
 ssq = function(a) {
   t(as.vector(c(as.matrix(a))))%*%as.vector(c(as.matrix(a)))
-}
\ No newline at end of file
+}
